//
//  ViewController.swift
//  TestLottieAnimation
//
//  Created by Tung Nguyen on 03/04/2024.
//

import UIKit
import Lottie
class ViewController: UIViewController {
    @IBOutlet weak var constraintHeightLoadingView: NSLayoutConstraint!

    @IBOutlet weak var lottieContainerView: UIView!
    override func viewDidLoad() {
        super.viewDidLoad()
        if let loadingView = makeLoadingView() {
            lottieContainerView.addSubview(loadingView)
            loadingView.translatesAutoresizingMaskIntoConstraints = false
            lottieContainerView.addSubview(loadingView)
            NSLayoutConstraint.activate([
                loadingView.topAnchor.constraint(equalTo: lottieContainerView.topAnchor),
                loadingView.bottomAnchor.constraint(equalTo: lottieContainerView.bottomAnchor),
                loadingView.leadingAnchor.constraint(equalTo: lottieContainerView.leadingAnchor),
                loadingView.trailingAnchor.constraint(equalTo: lottieContainerView.trailingAnchor)
            ])
        }
    }

    @IBAction func didTouchStartAnimation(_ sender: UIButton) {
        UIView.animate(withDuration: 2.0, animations: {
            if !sender.isSelected {
                self.constraintHeightLoadingView.constant = 40
            } else {
                self.constraintHeightLoadingView.constant = 200
            }
            self.view.layoutIfNeeded()
            self.lottieContainerView.layoutIfNeeded()
        }, completion: { _ in
        })
        sender.isSelected = !sender.isSelected
    }

    private func makeLoadingView() -> UIView? {
        let animationView = LottieAnimationView(
            animation: .named(
                "Boat_Loader",
                bundle: Bundle(for: type(of: self))
            )
        )
//        let animationView = AnimationView(name: "Boat_Loader")
        animationView.loopMode = .loop
        animationView.contentMode = .scaleAspectFill
        animationView.layer.borderColor = UIColor.red.cgColor
        animationView.layer.borderWidth = 1
        animationView.play()
        animationView.translatesAutoresizingMaskIntoConstraints = false

        return animationView
    }
}

